CacheStats

Struct CacheStats 

pub struct CacheStats {
    pub hits: u64,
    pub misses: u64,
    pub evictions: u64,
    pub expired_evictions: u64,
    pub total_bytes: u64,
    pub entry_count: u64,
}
Cumulative statistics for a BlockCache.

Fields

hits: u64

Total number of successful cache lookups.

misses: u64

Total number of failed cache lookups (including expired-entry misses).

evictions: u64

Total number of entries evicted due to capacity pressure.

expired_evictions: u64

Subset of misses caused by an expired entry being removed.

total_bytes: u64

Current aggregate size (bytes) of all live entries.

entry_count: u64

Current number of live entries.

Implementations

Source

impl CacheStats

pub fn hit_rate(&self) -> f64

Returns the fraction of lookups that were satisfied from the cache.

Returns 0.0 when neither hits nor misses have been recorded yet.