pub struct BcmCacheConfig {
pub max_hot_bytes: u64,
pub max_warm_bytes: u64,
pub max_cold_bytes: u64,
pub hot_threshold: u64,
pub warm_threshold: u64,
pub eviction_policy: EvictionPolicy,
}Expand description
Configuration for BlockCacheManager.
Note: named BcmCacheConfig to avoid collision with the CacheConfig in
ipfrs-storage::cache.
Fields
max_hot_bytes: u64Maximum total bytes that may reside in the Hot tier.
max_warm_bytes: u64Maximum total bytes that may reside in the Warm tier.
max_cold_bytes: u64Maximum total bytes that may reside in the Cold tier.
hot_threshold: u64Minimum access_count required to promote a block to Hot.
warm_threshold: u64Minimum access_count required to promote a block to Warm (must be < hot_threshold).
eviction_policy: EvictionPolicyEviction algorithm to use within each tier.