pub struct Chunk {
pub hash: ChunkHash,
pub offset: u64,
pub length: usize,
pub ref_count: u32,
pub compressed: bool,
}Expand description
Metadata record for a single stored chunk.
Note: in lib.rs this is re-exported as BddChunk to avoid collision
with chunk_manager::Chunk.
Fields
hash: ChunkHashContent-defined hash of this chunk’s raw bytes.
offset: u64Byte offset of this chunk’s first occurrence in the original object.
length: usizeLength in bytes of the raw (uncompressed) chunk data.
ref_count: u32Number of live references to this chunk across all stored objects.
compressed: boolWhether the stored bytes in the chunk store are compressed.