Module compaction

Module compaction 

Sled compaction scheduling with lock-free atomics.

CompactionScheduler tracks write activity and decides when to trigger a Sled WAL flush / compaction. All state is held in atomics so the scheduler is cheaply shareable across threads without any mutex.

Decision logic

A compaction is recommended when any of the following hold and no compaction is already in progress:

Structs

CompactionConfig
Configuration for automatic Sled compaction scheduling.
CompactionScheduler
Lock-free compaction scheduler for Sled block stores.