pub struct StorageCompressionRegistry {
pub profiles: HashMap<CompressionCodec, CodecProfile>,
}Expand description
Registry that tracks compression codec profiles and recommends a codec based on observed performance data and data characteristics.
Example
use ipfrs_storage::compression_registry::{
StorageCompressionRegistry, CompressionCodec, DataCharacteristics,
};
let mut registry = StorageCompressionRegistry::new();
registry.record_usage(CompressionCodec::Zstd, 1024, 400, 480, 90);
let chars = DataCharacteristics {
size_bytes: 4096,
is_text: false,
is_already_compressed: false,
latency_sensitive: false,
};
let rec = registry.recommend(&chars);
println!("Recommended: {:?} — {}", rec.codec, rec.reason);Fields
profiles: HashMap<CompressionCodec, CodecProfile>Per-codec runtime profiles.
Implementations
Sourceimpl StorageCompressionRegistry
impl StorageCompressionRegistry
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new registry pre-populated with default profiles for all five codecs.
Default values are based on typical real-world measurements:
| Codec | avg_ratio | compress µs | decompress µs |
|---|---|---|---|
| Zstd | 0.40 | 500 | 100 |
| Lz4 | 0.60 | 50 | 30 |
| Snappy | 0.70 | 100 | 50 |
| Brotli | 0.35 | 2000 | 100 |
| None | 1.00 | 1 | 1 |
Sourcepub fn record_usage(
&mut self,
codec: CompressionCodec,
original_bytes: u64,
compressed_bytes: u64,
compress_micros: u64,
decompress_micros: u64,
)
pub fn record_usage( &mut self, codec: CompressionCodec, original_bytes: u64, compressed_bytes: u64, compress_micros: u64, decompress_micros: u64, )
Record a compression event and update the codec profile.
For the first use (uses == 0 before the call) the measurements are
stored directly. For subsequent uses an exponential moving average
(α = 0.1) is applied:
new_value = 0.9 * old_value + 0.1 * sampleArguments
codec— the codec that was used.original_bytes— uncompressed size.compressed_bytes— size after compression.compress_micros— time taken to compress.decompress_micros— time taken to decompress.
Sourcepub fn recommend(&self, data: &DataCharacteristics) -> CodecRecommendation
pub fn recommend(&self, data: &DataCharacteristics) -> CodecRecommendation
Recommend a compression codec for the given data characteristics.
Decision logic (in order of priority):
- Already compressed →
None(“already compressed”). - Very small block (< 256 B) →
None(“too small”). - Latency-sensitive →
Lz4(“latency optimized”). - Text data →
Brotli(“text compression”). - Otherwise → codec with the best
efficiency_score(excludingNone) (“best efficiency”).
Sourcepub fn get_profile(&self, codec: CompressionCodec) -> Option<&CodecProfile>
pub fn get_profile(&self, codec: CompressionCodec) -> Option<&CodecProfile>
Return a reference to the profile for the given codec, if present.
Sourcepub fn stats(&self) -> CompressionRegistryStats
pub fn stats(&self) -> CompressionRegistryStats
Compute aggregate statistics across all registered profiles.