pub struct Cac2Entry {
pub cid: Cac2Cid,
pub data: Vec<u8>,
pub access_count: u32,
pub inserted_at: u64,
pub last_accessed: u64,
pub tier: Cac2Tier,
}Expand description
Single entry stored in the hot or warm tier.
Fields
cid: Cac2CidContent identifier.
data: Vec<u8>Raw payload.
access_count: u32Number of times this entry has been accessed (reads only).
inserted_at: u64UNIX timestamp (seconds) when the entry was first inserted.
last_accessed: u64UNIX timestamp (seconds) of the most-recent access.
tier: Cac2TierCurrent tier.