pub enum GcError {
ObjectAlreadyExists(String),
ObjectNotFound(String),
ObjectPinned(String),
ObjectReferenced {
id: String,
ref_count: u32,
},
}Expand description
Errors that can occur during garbage-collection operations.
Variants
ObjectAlreadyExists(String)
An object with this id already exists in the store.
ObjectNotFound(String)
No object with this id exists in the store.
ObjectPinned(String)
The object is pinned and cannot be removed.
ObjectReferenced
The object still has active references and cannot be removed.