pub enum SyncOperation {
Upload {
cid: String,
to_mirror: MirrorId,
},
Download {
cid: String,
from_mirror: MirrorId,
},
Delete {
cid: String,
from_mirror: MirrorId,
},
Resolve {
conflict: SyncConflict,
resolution: MsConflictResolution,
},
}Expand description
A single operation within a SyncPlan.
Variants
Upload
Send a block from local to a remote mirror.
Download
Fetch a block from a remote mirror to local.
Delete
Remove a block from a mirror.
Resolve
Resolve a conflict according to a specified strategy.
Fields

conflict: SyncConflictThe detected conflict.

resolution: MsConflictResolutionThe chosen resolution strategy.