pub enum OstStorageTier {
Hot,
Warm,
Cold,
}Expand description
Three-level object storage tier hierarchy.
Ost prefix used to avoid collision with StorageTier in cold_storage,
lifecycle, tier_manager, and tier_migration_engine.
Variants
Hot
Hot tier — fastest access, highest cost, limited capacity.
Warm
Warm tier — balanced access speed, medium cost.
Cold
Cold tier — slowest access, cheapest, essentially unlimited capacity.
Implementations
Sourceimpl OstStorageTier
impl OstStorageTier
Sourcepub fn colder(self) -> Option<OstStorageTier>
pub fn colder(self) -> Option<OstStorageTier>
Returns the tier one level colder, or None if already at Cold.
Sourcepub fn hotter(self) -> Option<OstStorageTier>
pub fn hotter(self) -> Option<OstStorageTier>
Returns the tier one level hotter, or None if already at Hot.