pub enum VsError {
VersionNotFound(u64),
BranchNotFound(String),
BranchAlreadyExists(String),
MaxVersionsReached,
MaxBranchesReached,
}Expand description
Errors produced by ObjectVersionStore.
Variants
VersionNotFound(u64)
A requested version number does not exist.
BranchNotFound(String)
A requested branch name does not exist.
BranchAlreadyExists(String)
A branch with the given name already exists.
MaxVersionsReached
Store has reached its configured maximum number of versions.
MaxBranchesReached
Store has reached its configured maximum number of branches.