pub struct PeAccessEvent {
pub cid: String,
pub timestamp: u64,
pub access_type: PeAccessType,
}Expand description
A single storage access event recorded by the prefetch engine.
Fields
cid: StringThe CID of the accessed block.
timestamp: u64Unix timestamp in milliseconds at which the access occurred.
access_type: PeAccessTypeThe type of access.