pub enum ReplicationState {
Pending,
InProgress,
Completed,
Failed,
}Expand description
State of a single replica of a block (legacy type).
Variants
Pending
Replica has been registered but replication has not started.
InProgress
Replication is currently in progress.
Completed
Replication completed successfully.
Failed
Replication failed.