pub struct RmReplicationPolicy {
pub replication_factor: u32,
pub min_healthy_replicas: u32,
pub prefer_local: bool,
pub max_node_utilization: f64,
}Expand description
Policy governing how many replicas are maintained and which nodes are chosen.
Fields
replication_factor: u32Target number of replicas per CID.
min_healthy_replicas: u32Minimum number of healthy replicas required for a CID to be Healthy.
prefer_local: boolPrefer nodes that are in the same locality.
max_node_utilization: f64Nodes above this utilization fraction are not eligible for new replicas.