pub enum RetentionDecision {
Keep {
reason: String,
},
Expire {
reason: String,
},
Defer {
until_secs: u64,
},
}Expand description
Decision made by the retention policy engine for a block.
Variants
Keep
Keep the block with the given reason.
Expire
Expire (delete) the block with the given reason.
Defer
Defer the decision until the given Unix timestamp (seconds).