pub enum RetentionRule {
PinProtected,
MaxAge {
secs: u64,
},
MinAccessCount {
count: u64,
},
MaxSize {
bytes: u64,
},
TagRequires {
tag: String,
},
TagExcludes {
tag: String,
},
}Expand description
A single retention rule that can match a block and produce a decision.
Variants
PinProtected
Keep any block that is pinned.
MaxAge
Expire blocks whose age exceeds the given number of seconds.
MinAccessCount
Expire blocks whose access count is below the threshold AND that are older than 3600 s.
MaxSize
Expire blocks that exceed the given size in bytes.
TagRequires
Keep if the block has the required tag; expire otherwise.
TagExcludes
Expire if the block has the excluded tag; no match (continue) otherwise.