pub struct LegacySnapshotDiff {
pub added: Vec<String>,
pub removed: Vec<String>,
pub common: usize,
}Expand description
The difference between two legacy snapshots.
Fields
added: Vec<String>CIDs present in snapshot B but absent from snapshot A.
removed: Vec<String>CIDs present in snapshot A but absent from snapshot B.
common: usizeNumber of CIDs common to both snapshots.
Implementations