pub enum ReplicationOp {
Put {
cid: [u8; 32],
data_len: usize,
ts: u64,
},
Delete {
cid: [u8; 32],
ts: u64,
},
Sync {
since_ts: u64,
},
}Expand description
An individual replication operation waiting to be processed.
Variants
Put
Replicate a newly added block to all configured targets.
Fields
Delete
Propagate a block deletion to all configured targets.
Sync
Request a full incremental sync from all targets since a given timestamp.