pub struct SrmReplicationConfig {
pub policy: ReplicationPolicy,
pub min_replicas: usize,
pub max_replicas: usize,
pub retry_limit: usize,
pub batch_size: usize,
}Expand description
Configuration for StorageReplicationManager.
Fields
policy: ReplicationPolicyReplication strategy.
min_replicas: usizeMinimum number of healthy replicas required for normal operation.
max_replicas: usizeMaximum number of replication targets that may be registered.
retry_limit: usizeNumber of retry attempts for a failed replication before giving up.
batch_size: usizeNumber of pending operations to drain per StorageReplicationManager::process_batch call.