pub struct SnapshotDiff {
pub added_pages: Vec<PageId>,
pub modified_pages: Vec<PageId>,
pub removed_pages: Vec<PageId>,
pub size_delta: i64,
}Expand description
The difference between two snapshots (or between a snapshot and current).
Fields
added_pages: Vec<PageId>Pages that exist in b but not in a.
modified_pages: Vec<PageId>Pages that exist in both but with a different version.
removed_pages: Vec<PageId>Pages that exist in a but not in b.
size_delta: i64Net change in bytes: size(b) − size(a). May be negative.