pub struct BalancerStats {
pub total_tiers: usize,
pub over_target_tiers: usize,
pub total_move_tasks: usize,
pub total_bytes_to_move: u64,
}Expand description
Aggregate statistics about the current state of the balancer.
Fields
total_tiers: usizeTotal number of tiers registered with the balancer.
over_target_tiers: usizeNumber of tiers that are currently above their target utilization.
total_move_tasks: usizeNumber of move tasks waiting in the pending queue.
total_bytes_to_move: u64Sum of size_bytes across all pending move tasks.