Module wal

Module wal 

Write-Ahead Log (WAL) for crash-recovery of block store writes.

Operations are written to a sequential log before being applied, so interrupted writes can be replayed on restart.

Structs

StorageWalEntry
A single entry in the StorageWriteAheadLog.
StorageWalStats
Point-in-time statistics for a StorageWriteAheadLog.
StorageWriteAheadLog
In-memory write-ahead log for crash-safe block operations.
WalConfig
Configuration for StorageWriteAheadLog.
WalEntry
A single entry in the write-ahead log.
WalStats
Atomic statistics for a WriteAheadLog.
WalStatsSnapshot
A point-in-time snapshot of WalStats.
WriteAheadLog
In-memory write-ahead log providing crash-recovery for block store writes.

Enums

WalEntryKind
The kind of operation recorded in a StorageWalEntry.
WalError
Errors that can occur during WAL operations.
WalOp
A WAL operation that can be recorded.

Functions

fnv1a_32
Computes FNV-1a 32-bit hash of data.