pub struct BufferConfig {
pub max_buffered_entries: usize,
pub max_buffered_bytes: u64,
pub flush_interval_secs: u64,
}Expand description
Configuration knobs for StorageWriteAheadBuffer.
Fields
max_buffered_entries: usizeAuto-flush when the number of buffered (unflushed) entries reaches this limit.
max_buffered_bytes: u64Auto-flush when the total payload bytes of buffered Put ops reaches this limit.
flush_interval_secs: u64Auto-flush when the oldest unflushed entry is at least this many seconds old.