pub struct FlushResult {
pub flushed_count: usize,
pub from_seq: u64,
pub to_seq: u64,
pub total_bytes: u64,
}Expand description
Summary returned by StorageWriteAheadBuffer::flush.
Fields
flushed_count: usizeNumber of entries that were marked flushed in this batch.
from_seq: u64Lowest sequence number in the flush batch (u64::MAX when batch is empty).
to_seq: u64Highest sequence number in the flush batch (0 when batch is empty).
total_bytes: u64Sum of size_bytes for every Put operation in the flush batch.