Module write_journal

Module write_journal 

Storage Write Journal — append-only record of all storage mutations for crash recovery, audit, and replication purposes.

Structs

JournalCursor
Opaque cursor into the write journal.
JournalEntry
A single record in the write journal.
JournalStats
Aggregate statistics derived from the current state of the journal.
StorageWriteJournal
An append-only write journal that records all storage mutations.

Enums

JournalEntryKind
The kind of mutation recorded in a journal entry.

Functions

fnv1a
Computes the FNV-1a 64-bit hash of bytes.