pub struct JournalCursor {
pub last_sequence: u64,
}Expand description
Opaque cursor into the write journal.
Used to track the position of a consumer so that only new entries need
to be delivered on subsequent calls to StorageWriteJournal::entries_since.
Fields
last_sequence: u64The sequence number of the last entry seen by this cursor.
0 indicates the cursor is positioned before the very first entry.
Implementations
Sourceimpl JournalCursor
impl JournalCursor
Sourcepub fn is_at_start(&self) -> bool
pub fn is_at_start(&self) -> bool
Returns true when the cursor is positioned before any entry (i.e.,
last_sequence == 0).