Compaction advisor for data-driven storage compaction recommendations.
Analyzes storage state and provides recommendations for when and how to compact, merge, or drop data, based on configurable thresholds.
Structs
- Advisory
Thresholds - Configurable thresholds that drive the advisory logic.
- Compaction
Advice - The result of an advisory analysis: a set of recommended actions with contextual metadata.
- Compaction
Advisor - Analyses a
StorageMetricssnapshot against a set ofAdvisoryThresholdsand produces aCompactionAdvicedescribing what maintenance work should be performed. - Storage
Metrics - A snapshot of current storage system metrics used to drive advisory logic.
Enums
- Compaction
Action - A recommended compaction or maintenance action.